@@ -92,7 +92,9 @@ private Q_SLOTS:
     void testZip64EndOfCentralDirectory();
     void testZip64DataDescriptor();
     void testZip64ExtraZip64Size();
+    void testZip64ExtraZip64SizeFirst();
     void testZip64ExtraZip64Offset();
+    void testZipOssFuzzIssue433303801();
 
     void testRcc();
 
@@ -132,6 +134,9 @@ private Q_SLOTS:
     void test7ZipNamelessFile();
     void test7ZipMultipleNamelessFiles();
     void test7ZipReadNumber();
+    void test7ZipFileNameEndsInSlash();
+    void test7ZipOssFuzzIssues_data();
+    void test7ZipOssFuzzIssues();
 #if HAVE_OPENSSL_SUPPORT
     void test7ZipPasswordProtected();
 #endif
